@@ -28,19 +28,34 @@
 struct jambuf;
 
 typedef struct {
-	unsigned version;
+	bool is_set;
+	enum ip_version version;
 	struct ip_bytes bytes;
 	unsigned prefix_bits;
 } ip_cidr;
 
+#define PRI_CIDR "<cidr-%s:IPv%d["PRI_IP_BYTES"]/%u>"
+#define pri_cidr(A)							\
+		((A).is_set ? "set" : "unset"),				\
+		(A).version,						\
+		pri_ip_bytes((A).bytes),					\
+		(A).prefix_bits
+
+void pexpect_cidr(const ip_cidr a, where_t where);
+#define pcidr(A) pexpect_cidr(A, HERE)
+
 extern const ip_cidr unset_cidr;
 
-const struct ip_info *cidr_type(const ip_cidr *cidr);
-ip_address cidr_address(const ip_cidr *cidr);
+const struct ip_info *cidr_type(const ip_cidr *cidr);	/* handles NULL */
+const struct ip_info *cidr_info(const ip_cidr cidr);
 
-bool cidr_is_unset(const ip_cidr *cidr);
+ip_address cidr_address(const ip_cidr cidr);
 
 /* convert CIDR address/mask; does not judge the result */
+ip_cidr cidr_from_raw(where_t where, enum ip_version version,
+		      const struct ip_bytes bytes,
+		      unsigned prefix_bits);
+
 err_t numeric_to_cidr(shunk_t src, const struct ip_info *afi, ip_cidr *cidr);
 
 /*
@@ -50,8 +65,9 @@ err_t numeric_to_cidr(shunk_t src, const struct ip_info *afi, ip_cidr *cidr);
  * specific route)" and ::/128 as "Unspecified address". While these
  * addresses are valid, they don't specifically specify anything...
  */
-err_t cidr_specified(const ip_cidr *cidr);
-bool cidr_is_specified(const ip_cidr *cidr);
+
+err_t cidr_specified(const ip_cidr cidr);
+bool cidr_is_specified(const ip_cidr cidr);
 
 typedef struct {
 	char buf[sizeof(address_buf) + 4/*/128*/];
