@@ -19,7 +19,7 @@
 
 #include <stdint.h>
 #include <stdbool.h>
-#include <stdlib.h>		/* for size_t */
+#include <stddef.h>		/* for size_t */
 
 #include "err.h"
 #include "ip_port.h"
@@ -28,7 +28,8 @@
 struct jambuf;
 
 typedef struct {
-	bool any_port;
+	bool is_set;
+	bool has_port_wildcard;	/* i.e., must narrow port */
 	unsigned hport;		/* 1..65535; 0->0-65535 */
 	unsigned ipproto;	/* 1..255; 0->unset */
 } ip_protoport;
@@ -37,9 +38,6 @@ extern const ip_protoport unset_protoport;
 
 err_t ttoprotoport(const char *src, ip_protoport *protoport);
 
-bool protoport_is_set(const ip_protoport *protoport);
-bool protoport_has_any_port(const ip_protoport *protoport);
-
 typedef struct {
 	char buf[32+1+32+1+1];
 } protoport_buf;
