@@ -14,6 +14,12 @@
  * for more details.
  *
  */
+
+#ifndef KERNEL_NETLINK_REPLY_H
+#define KERNEL_NETLINK_REPLY_H
+
+#include <stddef.h>	/* for size_t */
+
 ssize_t netlink_read_reply(int sock, char **pbuf, size_t bufsize,
 				unsigned int seqnum, __u32 pid);
 /*
@@ -22,3 +28,5 @@ ssize_t netlink_read_reply(int sock, char **pbuf, size_t bufsize,
  * to 32KiB of data so always keep that much free.
  */
 #define NL_BUFMARGIN 32768
+
+#endif
