@@ -32,15 +32,15 @@
 static bool ah_proposal_ok(struct proposal_parser *parser,
 			   const struct proposal *proposal)
 {
-	impaired_passert(PROPOSAL_PARSER,
+	impaired_passert(proposal_parser, parser->policy->logger,
 			 next_algorithm(proposal, PROPOSAL_encrypt, NULL) == NULL);
-	impaired_passert(PROPOSAL_PARSER,
+	impaired_passert(proposal_parser, parser->policy->logger,
 			 next_algorithm(proposal, PROPOSAL_prf, NULL) == NULL);
-	impaired_passert(PROPOSAL_PARSER,
+	impaired_passert(proposal_parser, parser->policy->logger,
 			 next_algorithm(proposal, PROPOSAL_integ, NULL) != NULL);
 
 	/* ah=null is invalid */
-	if (!IMPAIR(ALLOW_NULL_NONE)) {
+	if (!impair.allow_null_none) {
 		FOR_EACH_ALGORITHM(proposal, integ, alg) {
 			/* passerts */
 			const struct integ_desc *integ = integ_desc(alg->desc);
@@ -56,13 +56,34 @@ static bool ah_proposal_ok(struct proposal_parser *parser,
 	return true;
 }
 
-static const struct ike_alg *default_v1_ah_integ[] = {
-#ifdef USE_SHA1
-	&ike_alg_integ_sha1.common,
-#endif
-	NULL,
+/*
+ * IKEv1:
+ */
+
+static const char default_v1_ah_proposals[] =
+	"SHA1_96" /*???*/
+	;
+
+const struct proposal_defaults v1_ah_defaults = {
+	.proposals = default_v1_ah_proposals,
 };
 
+/*
+ * IKEv2:
+ */
+
+static const char default_v2_ah_proposals[] =
+	"SHA2_512_256"
+	","
+	"SHA2_256_128"
+	","
+	/*
+	 * something strongswan might accept; bottom of the preference
+	 * list
+	 */
+	"SHA1_96"
+	;
+
 static const struct ike_alg *default_v2_ah_integ[] = {
 #ifdef USE_SHA2
 	&ike_alg_integ_sha2_512.common,
@@ -71,25 +92,25 @@ static const struct ike_alg *default_v2_ah_integ[] = {
 	NULL,
 };
 
-const struct proposal_defaults v1_ah_defaults = {
-	.integ = default_v1_ah_integ,
-};
-
 const struct proposal_defaults v2_ah_defaults = {
+	.proposals = default_v2_ah_proposals,
 	.integ = default_v2_ah_integ,
 };
 
+/*
+ * All together now ...
+ */
+
 const struct proposal_protocol ah_proposal_protocol = {
 	.name = "AH",
 	.ikev1_alg_id = IKEv1_ESP_ID,
-	.protoid = PROTO_IPSEC_AH,
 	.defaults = {
 		[IKEv1] = &v1_ah_defaults,
 		[IKEv2] = &v2_ah_defaults,
 	},
 	.proposal_ok = ah_proposal_ok,
-	.integ_alg_byname = integ_alg_byname,
-	.dh_alg_byname = dh_alg_byname,
+	.integ = true,
+	.dh = true,
 };
 
 /*
