@@ -496,15 +496,6 @@ void append_symkey_byte(PK11SymKey **lhs, uint8_t rhs,
 	append_symkey_bytes("result", lhs, &rhs, sizeof(rhs), logger);
 }
 
-void append_chunk_symkey(const char *name, chunk_t *lhs, PK11SymKey *rhs,
-			 struct logger *logger)
-{
-	chunk_t rhs_chunk = chunk_from_symkey(name, rhs, logger);
-	chunk_t new = clone_hunk_hunk(*lhs, rhs_chunk, name);
-	free_chunk_content(&rhs_chunk);
-	replace_chunk(lhs, new);
-}
-
 /*
  * Extract SIZEOF_SYMKEY bytes of keying material as a PRF key.
  *
