@@ -16,10 +16,11 @@
  */
 
 #include <string.h>
+#include <sys/socket.h>		/* for AF_INET/AF_INET6 */
 
 #include "ip_info.h"
 #include "ip_address.h"
-#include "libreswan/passert.h"
+#include "passert.h"
 #include "lswlog.h"		/* for bad_case() */
 
 /*
@@ -29,7 +30,7 @@ err_t data_to_address(const void *data, size_t sizeof_data,
 		      const struct ip_info *afi, ip_address *dst)
 {
 	if (afi == NULL) {
-		*dst = address_invalid;
+		*dst = unset_address;
 		return "unknown address family";
 	}
 	switch (afi->af) {
