@@ -63,7 +63,8 @@ monotime_t mononow(void)
 		 * caller.
 		 */
 		fatal_errno(PLUTO_EXIT_KERNEL_FAIL, &global_logger, errno,
-			    "clock_gettime(%d,...) in mononow() failed: ", monotime_clockid());
+			    "clock_gettime(%d,...) in mononow() failed",
+			    monotime_clockid());
 	}
 	/* OK */
 	return (monotime_t) {
