@@ -16,9 +16,12 @@
  */
 
 #include <time.h>	/* for clock_*() + clockid_t */
+#include <errno.h>
 
 #include "constants.h"	/* for memeq() which is clearly not a constant */
-#include "lswlog.h"	/* for libreswan_exit_log_errno() */
+#include "passert.h"
+#include "jambuf.h"
+#include "lswlog.h"		/* for fatal_errno() */
 
 #include "realtime.h"
 
@@ -29,11 +32,15 @@ realtime_t realtime(time_t time)
 	return (realtime_t) { { time, 0, }, };
 }
 
+realtime_t realtime_ms(intmax_t milliseconds)
+{
+	return (realtime_t) { .rt = timeval_ms(milliseconds), };
+}
+
 realtime_t realtimesum(realtime_t t, deltatime_t d)
 {
-	struct timeval dv = deltatimeval(d);
 	realtime_t s;
-	timeradd(&t.rt, &dv, &s.rt);
+	timeradd(&t.rt, &d.dt, &s.rt);
 	return s;
 }
 
@@ -42,9 +49,10 @@ bool is_realtime_epoch(realtime_t t)
 	return !timerisset(&t.rt);
 }
 
-bool realbefore(realtime_t a, realtime_t b)
+int realtime_sub_sign(realtime_t l, realtime_t r)
 {
-	return timercmp(&a.rt, &b.rt, <);
+	/* sign(l - r) */
+	return timeval_sub_sign(l.rt, r.rt);
 }
 
 deltatime_t realtimediff(realtime_t a, realtime_t b)
@@ -61,9 +69,16 @@ realtime_t realnow(void)
 {
 	struct timespec ts;
 	int e = clock_gettime(realtime_clockid(), &ts);
-	if (e != 0) {
-		libreswan_exit_log_errno(e, "clock_gettime(%d,...) call in realnow() failed",
-					 realtime_clockid());
+	if (e < 0) {
+		/*
+		 * This code assumes clock_gettime() always succeeds -
+		 * if it were expected to fail then there'd either be
+		 * a logger and/or a way to return the failure to the
+		 * caller.
+		 */
+		fatal_errno(PLUTO_EXIT_KERNEL_FAIL, &global_logger, errno,
+			    "clock_gettime(%d,...) call in realnow() failed",
+			    realtime_clockid());
 	}
 	realtime_t t = {
 		.rt = {
@@ -76,7 +91,7 @@ realtime_t realnow(void)
 
 struct timespec realtime_as_timespec(realtime_t t)
 {
-	struct timespec ts =  {
+	struct timespec ts = {
 		.tv_sec = t.rt.tv_sec,
 		.tv_nsec = t.rt.tv_usec * 1000,
 	};
@@ -106,7 +121,7 @@ struct realtm utc_realtime(realtime_t t)
 /*
  *  Display a date either in local or UTC time
  */
-size_t jam_realtime(jambuf_t *buf, const realtime_t rtm, bool utc)
+size_t jam_realtime(struct jambuf *buf, const realtime_t rtm, bool utc)
 {
 	static const char *months[] = {
 		"Jan", "Feb", "Mar", "Apr", "May", "Jun",
@@ -127,7 +142,7 @@ size_t jam_realtime(jambuf_t *buf, const realtime_t rtm, bool utc)
 
 const char *str_realtime(realtime_t r, bool utc, realtime_buf *buf)
 {
-	jambuf_t jambuf = ARRAY_AS_JAMBUF(buf->buf);
+	struct jambuf jambuf = ARRAY_AS_JAMBUF(buf->buf);
 	jam_realtime(&jambuf, r, utc);
 	return buf->buf;
 }
