@@ -17,14 +17,16 @@
 
 #include <string.h>
 
-#include "libreswan.h"
+#include "ttodata.h"
+
 #include "hunk.h"		/* for char_to_lower() */
+#include "passert.h"
 
 /* converters and misc */
 static int unhex(const char *, char *, size_t);
 static int unb64(const char *, char *, size_t);
 static int untext(const char *, char *, size_t);
-static const char *badch(const char *, int, char *, size_t);
+static err_t badch(void);
 
 /* internal error codes for converters */
 #define SHORT (-2)	/* internal buffer too short */
@@ -43,15 +45,14 @@ static const char *badch(const char *, int, char *, size_t);
  *
  * Return NULL on success, else literal or errp
  */
-const char *ttodatav(const char *src,
-		     size_t srclen,	/* 0 means apply strlen() */
-		     int base,		/* 0 means figure it out */
-		     char *dst,		/* need not be valid if dstlen is 0 */
-		     size_t dstlen,
-		     size_t *lenp,	/* where to record length (NULL is nowhere) */
-		     char *errp,	/* error buffer */
-		     size_t errlen,
-		     unsigned int flags)
+#define TTODATAV_IGNORE_BASE64_SPACES  (1 << 1)  /* ignore spaces in base64 encodings */
+
+static const char *ttodatav(const char *src, size_t srclen,
+			    int base,		/* 0 means figure it out */
+			    char *dst,		/* need not be valid if dstlen is 0 */
+			    size_t dstlen,
+			    size_t *lenp,	/* where to record length (NULL is nowhere) */
+			    lset_t flags	/*XXX: always LEMPTY*/)
 {
 	size_t ingroup;	/* number of input bytes converted at once */
 	char buf[4];	/* output from conversion */
@@ -61,10 +62,8 @@ const char *ttodatav(const char *src,
 	int ndone;
 	int i;
 	int underscoreok;
-	int skipSpace = 0;
+	bool skipSpace = false;
 
-	if (srclen == 0)
-		srclen = strlen(src);
 	if (dstlen == 0)
 		dst = buf;	/* point it somewhere valid */
 	stop = dst + dstlen;
@@ -104,8 +103,8 @@ const char *ttodatav(const char *src,
 		decode = unb64;
 		underscoreok = 0;
 		ingroup = 4;
-		if (flags & TTODATAV_IGNORESPACE)
-			skipSpace = 1;
+		if (flags & TTODATAV_IGNORE_BASE64_SPACES)
+			skipSpace = true;
 		break;
 
 	case 256:
@@ -140,7 +139,7 @@ const char *ttodatav(const char *src,
 		case BADCH1:
 		case BADCH2:
 		case BADCH3:
-			return badch(stage, nbytes, errp, errlen);
+			return badch();
 
 		case SHORT:
 			return "internal buffer too short (\"can't happen\")";
@@ -188,8 +187,27 @@ const char *ttodata(const char *src,
 		    size_t dstlen,
 		    size_t *lenp)	/* where to record length (NULL is nowhere) */
 {
-	return ttodatav(src, srclen, base, dst, dstlen, lenp, (char *)NULL,
-			(size_t)0, TTODATAV_SPACECOUNTS);
+	/* zero means apply strlen() */
+	if (srclen == 0)
+		srclen = strlen(src);
+	return ttodatav(src, srclen, base, dst, dstlen, lenp, LEMPTY);
+}
+
+const char *ttochunk(shunk_t src,
+		     int base,		/* 0 means figure it out */
+		     chunk_t *dst)
+{
+	size_t size = 0;
+	err_t err = ttodatav(src.ptr, src.len, base, NULL/*dst*/, 0/*dstlen*/, &size, LEMPTY);
+	if (err != NULL) {
+		return err;
+	}
+	passert(size > 0); /* see pdone variable above */
+	*dst = alloc_chunk(size, "ttochunk");
+	err = ttodatav(src.ptr, src.len, base, (char*)dst->ptr, dst->len, &size, LEMPTY);
+	passert(err == NULL);
+	passert(dst->len == size);
+	return NULL;
 }
 
 /*
@@ -319,12 +337,20 @@ static int untext(const char *src,	/* known to be full length */
  * size, that means the TTODATAV_BUF constant has been set too small.
  *
  * Return literal or errp
+ *
+ * Rewrite to return diag_t.
  */
-static const char *badch(const char *src,
-			 int errcode,
-			 char *errp,	/* might be NULL */
-			 size_t errlen)
+static err_t badch(void)
+/*
+  (const char *src,
+   int errcode,
+   char *errp,	// might be NULL
+   size_t errlen)
+*/
 {
+#if 1
+	return "unknown character in input";
+#else
 	static const char pre[] = "unknown character (`";
 	static const char suf[] = "') in input";
 	char buf[5];
@@ -357,6 +383,7 @@ static const char *badch(const char *src,
 	strcat(errp, buf);
 	strcat(errp, suf);
 	return (const char *)errp;
+#endif
 }
 
 #ifdef TTODATA_MAIN
@@ -399,7 +426,7 @@ int main(int argc, char *argv[])
 	}
 
 	oops = ttodatav(argv[1], 0, 0, buf, sizeof(buf), &n,
-			err, sizeof(err), TTODATAV_IGNORESPACE);
+			err, sizeof(err), LEMPTY);
 	if (oops != NULL) {
 		fprintf(stderr, "%s: ttodata error `%s' in `%s'\n", pgm,
 			oops, argv[1]);
@@ -674,12 +701,12 @@ char *pgm;
 				ttodatav(r->ascii, 0, base, buf, sizeof(buf),
 					&n,
 					NULL,
-					0, TTODATAV_IGNORESPACE), &status);
+					0, TTODATAV_IGNORE_BASE64_SPACES), &status);
 			if (xbase != 0)
 				check(r, buf, n,
 					ttodatav(r->ascii + 2, 0, xbase, buf,
 						sizeof(buf), &n, NULL, 0,
-						TTODATAV_IGNORESPACE), &status);
+						TTODATAV_IGNORE_BASE64_SPACES), &status);
 		} else {
 			check(r, buf, n,
 				ttodata(r->ascii, 0, base, buf, sizeof(buf),
@@ -689,7 +716,7 @@ char *pgm;
 					ttodatav(r->ascii, 0, base, buf,
 						sizeof(buf),
 						&n, NULL, 0,
-						TTODATAV_IGNORESPACE), &status);
+						TTODATAV_IGNORE_BASE64_SPACES), &status);
 
 			if (xbase != 0) {
 				check(r, buf, n,
@@ -701,7 +728,7 @@ char *pgm;
 							buf,
 							sizeof(buf), &n, NULL,
 							0,
-							TTODATAV_IGNORESPACE),
+							TTODATAV_IGNORE_BASE64_SPACES),
 						&status);
 			}
 		}
