@@ -12,10 +12,19 @@
  * for more details.
  */
 
+#ifndef FOODGROUPS_H
+#define FOODGROUPS_H
+
 struct connection;      /* forward declaration */
+struct logger;
+
 extern void add_group(struct connection *c);
 extern void route_group(struct connection *c);
 extern void unroute_group(struct connection *c);
 extern void delete_group(const struct connection *c);
 
-extern void load_groups(void);
+extern void load_groups(struct logger *logger);
+
+void free_foodgroups(void);
+
+#endif
