@@ -165,6 +165,7 @@
 #include "ip_selector.h"
 #include "unpack.h"
 #include "pending.h"
+#include "rekeyfuzz.h"
 
 #ifdef HAVE_NM
 #include "kernel.h"
@@ -1604,16 +1605,23 @@ void process_v1_packet(struct msg_digest *md)
 				} else if (frag->index == last_frag_index) {
 					struct msg_digest *whole_md = alloc_md(frag->md->iface,
 									       &frag->md->sender,
+									       NULL/*packet*/, size,
 									       HERE);
-					uint8_t *buffer = alloc_bytes(size,
-								      "IKE fragments buffer");
-					size_t offset = 0;
 
-					/* Reassemble fragments in buffer */
+					/*
+					 * Reassemble fragments in
+					 * buffer.
+					 *
+					 * Header is taken directly
+					 * from first fragment.
+					 *
+					 * XXX: DANGER! this code is
+					 * re-using FRAG.
+					 */
 					frag = st->st_v1_rfrags;
-					while (frag != NULL &&
-					       frag->index <= last_frag_index)
-					{
+					uint8_t *buffer = whole_md->packet_pbs.start;
+					size_t offset = 0;
+					while (frag != NULL && frag->index <= last_frag_index) {
 						passert(offset + frag->size <=
 							size);
 						memcpy(buffer + offset,
@@ -1622,10 +1630,14 @@ void process_v1_packet(struct msg_digest *md)
 						frag = frag->next;
 					}
 
-					init_pbs(&whole_md->packet_pbs, buffer, size,
-						 "packet");
-
-					process_packet(&whole_md);
+					/*
+					 * process_md() calls
+					 * process_v1_packet(), but
+					 * only after first
+					 * initializing .hdr and
+					 * .message_pbs.
+					 */
+					process_md(whole_md);
 					md_delref(&whole_md);
 					free_v1_message_queues(st);
 					/* optimize: if receiving fragments, immediately respond with fragments too */
@@ -2598,12 +2610,6 @@ void complete_v1_state_transition(struct state *st, struct msg_digest *md, stf_s
 			 * Responder, and the dictated time is
 			 * acceptable, plan to EXPIRE.
 			 *
-			 * Important policy lies buried here.  For
-			 * example, we favour the initiator over the
-			 * responder by making the initiator start
-			 * rekeying sooner.  Also, fuzz is only added
-			 * to the initiator's margin.
-			 *
 			 * Note: for ISAKMP SA, we let the negotiated
 			 * time stand (implemented by earlier logic).
 			 */
@@ -2614,25 +2620,15 @@ void complete_v1_state_transition(struct state *st, struct msg_digest *md, stf_s
 					      EVENT_SA_EXPIRE);
 			}
 			if (event_type != EVENT_SA_EXPIRE) {
-				time_t marg_s = deltasecs(c->sa_rekey_margin);
-
-				if (smc->flags & SMF_INITIATOR) {
-					marg_s += marg_s *
-						c->sa_rekey_fuzz /
-						100.E0 *
-						(rand() /
-						 (RAND_MAX + 1.E0));
-				} else {
-					marg_s /= 2;
-				}
-				deltatime_t marg = deltatime(marg_s);
-
+				deltatime_t marg = fuzz_rekey_margin(st->st_sa_role,
+								     c->sa_rekey_margin,
+								     c->sa_rekey_fuzz/*percent*/);
 				if (deltatime_cmp(event_delay, >, marg)) {
-					event_delay = deltatime_sub(event_delay, marg);
 					st->st_replace_margin = marg;
 				} else {
-					event_type = EVENT_SA_EXPIRE;
+					marg = deltatime(0);
 				}
+				event_delay = deltatime_sub(event_delay, marg);
 			}
 			event_schedule(event_type, event_delay, st);
 			break;
@@ -2880,17 +2876,6 @@ void complete_v1_state_transition(struct state *st, struct msg_digest *md, stf_s
 	}
 }
 
-bool ikev1_ship_chain(chunk_t *chain, int n, pb_stream *outs,
-		      uint8_t type)
-{
-	for (int i = 0; i < n; i++) {
-		if (!ikev1_ship_CERT(type, HUNK_AS_SHUNK(chain[i]), outs))
-			return false;
-	}
-
-	return true;
-}
-
 void doi_log_cert_thinking(uint16_t auth,
 			   enum ike_cert_type certtype,
 			   enum certpolicy policy,
