@@ -9,15 +9,19 @@
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.  See <http://www.fsf.org/copyleft/gpl.txt>.
+ * option) any later version.  See <https://www.gnu.org/licenses/gpl2.txt>.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  */
+
+#ifndef IKEV1_DPD_H
+#define IKEV1_DPD_H
+
 extern stf_status dpd_init(struct state *st);
-extern void dpd_event(struct state *st);
+extern void event_v1_dpd(struct state *st);
 
 extern stf_status dpd_inI_outR(struct state *st,
 			       struct isakmp_notification *const n,
@@ -25,6 +29,8 @@ extern stf_status dpd_inI_outR(struct state *st,
 extern stf_status dpd_inR(struct state *st,
 			  struct isakmp_notification *const n,
 			  pb_stream *pbs);
-extern void dpd_timeout(struct state *st);
+extern void event_v1_dpd_timeout(struct state *st);
 
 #define DPD_RETRANS_MAX 3
+
+#endif
