@@ -174,17 +174,15 @@ static bool emit_subnet_id(const ip_subnet net,
 		return false;
 
 	ip_address tp = subnet_prefix(net);
-	diag_t d = pbs_out_address(&id_pbs, tp, "client network");
-	if (d != NULL) {
-		llog_diag(RC_LOG_SERIOUS, outs->outs_logger, &d, "%s", "");
+	if (!pbs_out_address(&id_pbs, tp, "client network")) {
+		/* already logged */
 		return false;
 	}
 
 	if (!usehost) {
 		ip_address tm = subnet_prefix_mask(net);
-		diag_t d = pbs_out_address(&id_pbs, tm, "client mask");
-		if (d != NULL) {
-			llog_diag(RC_LOG_SERIOUS, outs->outs_logger, &d, "%s", "");
+		if (!pbs_out_address(&id_pbs, tm, "client mask")) {
+			/* already logged */
 			return false;
 		}
 	}
@@ -327,34 +325,32 @@ static void compute_proto_keymat(struct state *st,
 		bad_case(protoid);
 	}
 
-	pi->keymat_len = needed_len;
+	free_chunk_content(&pi->inbound.keymat);
+	pi->inbound.keymat = ikev1_section_5_keymat(st->st_oakley.ta_prf,
+						    st->st_skeyid_d_nss,
+						    st->st_dh_shared_secret,
+						    protoid,
+						    THING_AS_SHUNK(pi->inbound.spi),
+						    st->st_ni, st->st_nr,
+						    needed_len,
+						    st->st_logger);
+	PASSERT(st->st_logger, pi->inbound.keymat.len == needed_len);
 
-	pfreeany(pi->our_keymat);
-	pi->our_keymat = ikev1_section_5_keymat(st->st_oakley.ta_prf,
-						st->st_skeyid_d_nss,
-						st->st_dh_shared_secret,
-						protoid,
-						THING_AS_SHUNK(pi->our_spi),
-						st->st_ni, st->st_nr,
-						needed_len,
-						st->st_logger).ptr;
-
-	pfreeany(pi->peer_keymat);
-	pi->peer_keymat = ikev1_section_5_keymat(st->st_oakley.ta_prf,
-						 st->st_skeyid_d_nss,
-						 st->st_dh_shared_secret,
-						 protoid,
-						 THING_AS_SHUNK(pi->attrs.spi),
-						 st->st_ni, st->st_nr,
-						 needed_len,
-						 st->st_logger).ptr;
+	free_chunk_content(&pi->outbound.keymat);
+	pi->outbound.keymat = ikev1_section_5_keymat(st->st_oakley.ta_prf,
+						     st->st_skeyid_d_nss,
+						     st->st_dh_shared_secret,
+						     protoid,
+						     THING_AS_SHUNK(pi->outbound.spi),
+						     st->st_ni, st->st_nr,
+						     needed_len,
+						     st->st_logger);
+	PASSERT(st->st_logger, pi->outbound.keymat.len == needed_len);
 
 	if (DBGP(DBG_CRYPT)) {
 		DBG_log("%s KEYMAT", satypename);
-		DBG_dump("  KEYMAT computed:", pi->our_keymat,
-			 pi->keymat_len);
-		DBG_dump("  Peer KEYMAT computed:", pi->peer_keymat,
-			 pi->keymat_len);
+		DBG_dump_hunk("  inbound:", pi->inbound.keymat);
+		DBG_dump_hunk("  outbound:", pi->outbound.keymat);
 	}
 }
 
@@ -690,12 +686,10 @@ void quick_outI1(struct fd *whack_sock,
 
 	if (policy & POLICY_PFS) {
 		submit_ke_and_nonce(st, st->st_pfs_group,
-				    quick_outI1_continue,
-				    "quick_outI1 KE");
+				    quick_outI1_continue, HERE);
 	} else {
 		submit_ke_and_nonce(st, NULL /* no-nonce*/,
-				    quick_outI1_continue,
-				    "quick_outI1 KE");
+				    quick_outI1_continue, HERE);
 	}
 }
 
@@ -1142,7 +1136,7 @@ static stf_status quick_inI1_outR1_tail(struct state *p1st, struct msg_digest *m
 			c->spd.that.client = *remote_client;
 			rehash_db_spd_route_remote_client(&c->spd);
 			c->spd.that.has_client = true;
-			virtual_ip_delref(&c->spd.that.virt, HERE);
+			virtual_ip_delref(&c->spd.that.virt);
 
 			if (selector_eq_address(*remote_client, c->remote->host.addr)) {
 				c->spd.that.has_client = false;
@@ -1249,8 +1243,7 @@ static stf_status quick_inI1_outR1_tail(struct state *p1st, struct msg_digest *m
 		passert(st->st_connection != NULL);
 
 		submit_ke_and_nonce(st, st->st_pfs_group/*possibly-null*/,
-				    quick_inI1_outR1_continue1,
-				    "quick_inI1_outR1_tail");
+				    quick_inI1_outR1_continue1, HERE);
 
 		passert(st->st_connection != NULL);
 		return STF_SUSPEND;
