@@ -21,4 +21,4 @@ extern void quick_outI1(struct fd *whack_sock,
 			lset_t policy,
 			unsigned long try,
 			so_serial_t replacing,
-			chunk_t sec_label);
+			shunk_t sec_label);
