@@ -42,12 +42,6 @@ extern void complete_v2_state_transition(struct ike_sa *ike,
 void schedule_reinitiate_v2_ike_sa_init(struct ike_sa *ike,
 					stf_status (*resume)(struct ike_sa *ike));
 
-extern bool ikev2_calculate_rsa_hash(struct ike_sa *ike,
-				     const struct crypt_mac *idhash,
-				     pb_stream *a_pbs,
-				     chunk_t *no_ppk_auth /* optional output */,
-				     const struct hash_desc *hash_algo);
-
 struct crypt_mac ikev2_rsa_sha1_hash(const struct crypt_mac *hash);
 
 extern bool ikev2_emit_psk_auth(enum keyword_auth authby,
@@ -176,6 +170,7 @@ bool v2_notification_fatal(v2_notification_t n);
 
 bool already_has_larval_v2_child(struct ike_sa *ike, const struct connection *c);
 
+void llog_v2_success_sent_message_to(struct ike_sa *ike);
 void llog_v2_success_story(struct ike_sa *ike);
 void llog_v2_success_exchange(struct ike_sa *ike);
 void llog_v2_success_story_details(struct ike_sa *ike);
