@@ -344,19 +344,17 @@ static bool record_v2_rekey_ike_message(struct ike_sa *ike,
 			.isag_critical = build_ikev2_critical(false, larval_ike->sa.st_logger),
 		};
 		struct pbs_out nr_pbs;
-		diag_t d;
-		d = pbs_out_struct(message.pbs, &ikev2_nonce_desc, &in, sizeof(in), &nr_pbs);
-		if (d != NULL) {
-			llog_diag(RC_LOG_SERIOUS, larval_ike->sa.st_logger, &d, "%s", "");
-			return false;
+
+		if (!pbs_out_struct(message.pbs, &ikev2_nonce_desc, &in, sizeof(in), &nr_pbs)) {
+			/* already logged */
+			return false; /*fatal*/
 		}
 
 		chunk_t local_nonce = ((larval_ike->sa.st_sa_role == SA_INITIATOR) ? larval_ike->sa.st_ni :
 				       (larval_ike->sa.st_sa_role == SA_RESPONDER) ? larval_ike->sa.st_nr :
 				       empty_chunk);
-		d = pbs_out_hunk(&nr_pbs, local_nonce, "IKEv2 nonce");
-		if (d != NULL) {
-			llog_diag(RC_LOG_SERIOUS, larval_ike->sa.st_logger, &d, "%s", "");
+		if (!pbs_out_hunk(&nr_pbs, local_nonce, "IKEv2 nonce")) {
+			/* already logged */
 			return false;
 		}
 
@@ -434,8 +432,7 @@ struct child_sa *submit_v2_CREATE_CHILD_SA_rekey_child(struct ike_sa *ike,
 	    pri_shunk(c->spd.this.sec_label));
 
 	submit_ke_and_nonce(&larval_child->sa, larval_child->sa.st_pfs_group /*possibly-null*/,
-			    queue_v2_CREATE_CHILD_SA_rekey_child_request,
-			    "Child Rekey Initiator KE and nonce ni");
+			    queue_v2_CREATE_CHILD_SA_rekey_child_request, HERE);
 
 	return larval_child;
 }
@@ -588,10 +585,10 @@ stf_status initiate_v2_CREATE_CHILD_SA_rekey_child_request(struct ike_sa *ike,
 		enum ikev2_sec_proto_id rekey_protoid;
 		ipsec_spi_t rekey_spi;
 		if (prev->sa.st_esp.present) {
-			rekey_spi = prev->sa.st_esp.our_spi;
+			rekey_spi = prev->sa.st_esp.inbound.spi;
 			rekey_protoid = PROTO_IPSEC_ESP;
 		} else if (prev->sa.st_ah.present) {
-			rekey_spi = prev->sa.st_ah.our_spi;
+			rekey_spi = prev->sa.st_ah.inbound.spi;
 			rekey_protoid = PROTO_IPSEC_AH;
 		} else {
 			llog_pexpect(larval_child->sa.st_logger, HERE,
@@ -708,8 +705,7 @@ void submit_v2_CREATE_CHILD_SA_new_child(struct ike_sa *ike,
 	    larval_child->sa.st_pfs_group == NULL ? "no-pfs" : larval_child->sa.st_pfs_group->common.fqn);
 
 	submit_ke_and_nonce(&larval_child->sa, larval_child->sa.st_pfs_group /*possibly-null*/,
-			    queue_v2_CREATE_CHILD_SA_new_child_request,
-			    "Child Initiator KE? and nonce");
+			    queue_v2_CREATE_CHILD_SA_new_child_request, HERE);
 }
 
 static void llog_v2_success_new_child_request(struct ike_sa *ike)
@@ -929,8 +925,7 @@ stf_status process_v2_CREATE_CHILD_SA_request(struct ike_sa *ike,
 	 */
 	submit_ke_and_nonce(&ike->sa,
 			    larval_child->sa.st_pfs_group != NULL ? larval_child->sa.st_oakley.ta_dh : NULL,
-			    process_v2_CREATE_CHILD_SA_request_continue_1,
-			    "Child Rekey Responder KE and nonce nr");
+			    process_v2_CREATE_CHILD_SA_request_continue_1, HERE);
 	return STF_SUSPEND;
 }
 
@@ -1303,8 +1298,7 @@ struct child_sa *submit_v2_CREATE_CHILD_SA_rekey_ike(struct ike_sa *ike)
 	    larval_ike->sa.st_oakley.ta_dh->common.fqn);
 
 	submit_ke_and_nonce(&larval_ike->sa, larval_ike->sa.st_oakley.ta_dh,
-			    queue_v2_CREATE_CHILD_SA_rekey_ike_request,
-			    "IKE REKEY Initiator KE and nonce ni");
+			    queue_v2_CREATE_CHILD_SA_rekey_ike_request, HERE);
 	/* "return STF_SUSPEND" */
 	return larval_ike;
 }
@@ -1489,8 +1483,7 @@ stf_status process_v2_CREATE_CHILD_SA_rekey_ike_request(struct ike_sa *ike,
 	}
 
 	submit_ke_and_nonce(&ike->sa, larval_ike->sa.st_oakley.ta_dh,
-			    process_v2_CREATE_CHILD_SA_rekey_ike_request_continue_1,
-			    "IKE rekey KE response gir");
+			    process_v2_CREATE_CHILD_SA_rekey_ike_request_continue_1, HERE);
 	return STF_SUSPEND;
 }
 
