@@ -17,27 +17,16 @@
  * for more details.
  */
 
-#include "fd.h"
+#ifndef IPSEC_DOI_H
+#define IPSEC_DOI_H
+
 #include "pluto_timing.h"
 
+struct fd;
 struct payload_digest;
 struct state;
 struct jambuf;
 
-typedef void initiator_function(struct fd *whack_sock,
-				struct connection *c,
-				struct state *predecessor,
-				lset_t policy,
-				unsigned long try,
-				const threadtime_t *inception,
-				chunk_t sec_label);
-
-extern void ipsecdoi_initiate(struct fd *whack_sock, struct connection *c,
-			      lset_t policy, unsigned long try,
-			      so_serial_t replacing,
-			      const threadtime_t *inception,
-			      chunk_t sec_label);
-
 extern void ipsecdoi_replace(struct state *st, unsigned long try);
 
 extern void init_phase2_iv(struct state *st, const msgid_t *msgid);
@@ -46,16 +35,12 @@ extern bool accept_delete(struct msg_digest *md,
 			  struct payload_digest *p);
 extern void accept_self_delete(struct msg_digest *md);
 
-extern void send_notification_from_state(struct state *st,
-					 enum state_kind from_state,
-					 notification_t type);
-extern void send_notification_from_md(struct msg_digest *md, notification_t type);
-
 extern stf_status send_isakmp_notification(struct state *st,
 					   uint16_t type, const void *data,
 					   size_t len);
+extern void jam_child_sa_details(struct jambuf *buf, struct state *st);
+extern void jam_parent_sa_details(struct jambuf *buf, struct state *st);
 
-extern bool has_preloaded_public_key(const struct state *st);
+lset_t capture_child_rekey_policy(struct state *st);
 
-extern void lswlog_child_sa_established(struct jambuf *buf, struct state *st);
-extern void lswlog_ike_sa_established(struct jambuf *buf, struct state *st);
+#endif
