@@ -1,5 +1,6 @@
 /* format of ISAKMP message header
  * Copyright (C) 2014 D. Hugh Redelmeier <hugh@mimosa.com>
+ * Copyright (C) 2019 Andrew Cagney <cagney@gnu.org>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -18,6 +19,8 @@
  * Breaking this out allows packet.h to be private to Pluto.
  */
 
+#include "ike_spi.h"
+
 /* ISAKMP Header: for all messages
  * layout from RFC 2408 "ISAKMP" section 3.1
  *
@@ -45,12 +48,13 @@
 #define NSIZEOF_isakmp_generic	4	/* on-the-wire sizeof isakmp_generic) */
 
 struct isakmp_hdr {
-	uint8_t isa_icookie[COOKIE_SIZE];
-	uint8_t isa_rcookie[COOKIE_SIZE];
+#define isa_ike_initiator_spi isa_ike_spis.initiator
+#define isa_ike_responder_spi isa_ike_spis.responder
+	ike_spis_t isa_ike_spis;
 	uint8_t isa_np;	/* Next payload */
 	uint8_t isa_version;	/* high-order 4 bits: Major; low order 4: Minor */
 	uint8_t isa_xchg;	/* Exchange type */
 	uint8_t isa_flags;
-	uint32_t isa_msgid;	/* Message ID (RAW) */
+	uint32_t isa_msgid;	/* Message ID */
 	uint32_t isa_length;	/* Length of message */
 };
