@@ -41,6 +41,7 @@
 #include "log.h"
 #include "whack.h"
 #include "ikev1.h"	/* for ikev1_quick_dh() */
+#include "show.h"
 
 void show_kernel_alg_status(struct show *s)
 {
@@ -104,11 +105,11 @@ void show_kernel_alg_connection(struct show *s,
 		 * If this is NULL and PFS is required then callers fall back to using
 		 * the parent's DH algorithm.
 		 */
-		switch (c->ike_version) {
+		switch (c->config->ike_version) {
 #ifdef USE_IKEv1
 		case IKEv1:
 		{
-			const struct dh_desc *dh = ikev1_quick_pfs(c->child_proposals);
+			const struct dh_desc *dh = ikev1_quick_pfs(c->config->child_proposals);
 			if (dh != NULL) {
 				pfsbuf = dh->common.fqn;
 			} else {
@@ -131,8 +132,8 @@ void show_kernel_alg_connection(struct show *s,
 	 * known).  Mainly so that test output doesn't get churned
 	 * (originally it wasn't shown because it wasn't known).
 	 */
-	if (c->child_proposals.p != NULL &&
-	    !default_proposals(c->child_proposals.p)) {
+	if (c->config->child_proposals.p != NULL &&
+	    !default_proposals(c->config->child_proposals.p)) {
 		SHOW_JAMBUF(RC_COMMENT, s, buf) {
 			/*
 			 * If DH (PFS) was specified in the esp= or
@@ -153,11 +154,11 @@ void show_kernel_alg_connection(struct show *s,
 			 */
 			jam(buf, "\"%s\"%s:   %s algorithms: ",
 			    c->name, instance, satype);
-			jam_proposals(buf, c->child_proposals.p);
+			jam_proposals(buf, c->config->child_proposals.p);
 		}
 	}
 
-	const struct state *st = state_with_serialno(c->newest_ipsec_sa);
+	const struct state *st = state_by_serialno(c->newest_ipsec_sa);
 
 	if (st != NULL && st->st_esp.present) {
 		show_comment(s,
