@@ -26,6 +26,7 @@
 #include "nat_traversal.h"		/* for nat_traversal_enabled */
 #include "refcnt.h"
 #include "ip_info.h"
+#include "show.h"
 
 #define F_VIRTUAL_NO		1	/* %no (subnet must be host/32) */
 #define F_VIRTUAL_PRIVATE	2	/* %priv (list held in private_net_{incl,excl} */
@@ -489,12 +490,12 @@ void show_virtual_private(struct show *s)
 	}
 }
 
-struct virtual_ip *virtual_ip_addref(struct virtual_ip *vip, where_t where)
+struct virtual_ip *virtual_ip_addref_where(struct virtual_ip *vip, where_t where)
 {
 	return addref_where(vip, where);
 }
 
-void virtual_ip_delref(struct virtual_ip **vip, where_t where)
+void virtual_ip_delref_where(struct virtual_ip **vip, where_t where)
 {
 	delref_where(vip, where);
 }
