@@ -41,6 +41,7 @@
 #include "lswconf.h"
 #include "lswnss.h"
 #include "constants.h"
+#include "ttodata.h"
 
 #include "defs.h"
 #include "log.h"
@@ -67,6 +68,7 @@
 #include "certs.h"
 #include "root_certs.h"
 #include "iface.h"
+#include "show.h"
 
 /* new NSS code */
 #include "pluto_x509.h"
@@ -682,253 +684,6 @@ diag_t match_end_cert_id(const struct certs *certs,
 	}
 }
 
-/*
- * Decode the CERT payload of Phase 1.
- */
-/* todo:
- * https://tools.ietf.org/html/rfc4945
- *  3.3.4. PKCS #7 Wrapped X.509 Certificate
- *
- *  This type defines a particular encoding, not a particular certificate
- *  type.  Implementations SHOULD NOT generate CERTs that contain this
- *  Certificate Type.  Implementations SHOULD accept CERTs that contain
- *  this Certificate Type because several implementations are known to
- *  generate them.  Note that those implementations sometimes include
- *  entire certificate hierarchies inside a single CERT PKCS #7 payload,
- *  which violates the requirement specified in ISAKMP that this payload
- *  contain a single certificate.
- */
-
-/*
- * Decode the certs.  If something nasty happens, such as an expired
- * cert, return false.
- *
- * Only log failures, success is left to v2_verify_certs().
- */
-bool v1_decode_certs(struct msg_digest *md)
-{
-	struct state *st = md->v1_st;
-	passert(st->st_ike_version == IKEv1);
-
-	/*
-	 * At least one set of certs have been processed; and at least
-	 * once.
-	 *
-	 * The way this code is called is broken (see functions
-	 * ikev1_decode_peer_id*() and oakley_auth()):
-	 *
-	 * - it is repeatedly called to decode the same cert payload
-	 * (causing a cert payload the be decoded multiple times)
-	 *
-	 * - it is called to decode cert payloads that aren't there
-	 * (for instance the first aggressive request)
-	 */
-	st->st_remote_certs.processed = true;
-
-	struct payload_digest *cert_payloads = md->chain[ISAKMP_NEXT_CERT];
-	if (cert_payloads == NULL) {
-		return true;
-	}
-
-	if (st->st_remote_certs.verified != NULL) {
-		dbg("hacking around a redundant call to v1_process_certs() - releasing verified");
-		release_certs(&st->st_remote_certs.verified);
-	}
-	if (st->st_remote_certs.pubkey_db != NULL) {
-		dbg("hacking around a redundant call to v1_process_certs() - releasing pubkey_db");
-		free_public_keys(&st->st_remote_certs.pubkey_db);
-	}
-
-	if (!pexpect(st->st_remote_certs.verified == NULL)) {
-		/*
-		 * Since the MITM has already failed their first
-		 * attempt at proving their credentials, there's no
-		 * point in giving them a second chance.
-		 *
-		 * Happens because code rejecting the first
-		 * authentication attempt leaves the state as-is
-		 * instead of zombifying (where the notification is
-		 * recorded and then sent, and then the state
-		 * transitions to zombie where it can linger while
-		 * dealing with duplicate packets) or deleting it.
-		 */
-		return false;
-	}
-
-	statetime_t start = statetime_start(st);
-	struct connection *c = st->st_connection;
-
-	const struct rev_opts rev_opts = {
-		.ocsp = ocsp_enable,
-		.ocsp_strict = ocsp_strict,
-		.ocsp_post = ocsp_post,
-		.crl_strict = crl_strict,
-	};
-
-	struct root_certs *root_certs = root_certs_addref(HERE); /* must-release */
-	struct verified_certs certs = find_and_verify_certs(st->st_logger, st->st_ike_version,
-							    cert_payloads, &rev_opts,
-							    root_certs, &c->remote->host.id);
-	root_certs_delref(&root_certs, HERE);
-
-	/* either something went wrong, or there were no certs */
-	if (certs.cert_chain == NULL) {
-#if defined(LIBCURL) || defined(LIBLDAP)
-		if (certs.crl_update_needed && deltasecs(crl_check_interval) > 0) {
-			/*
-			 * When a strict crl check fails, the certs
-			 * are deleted and CRL_NEEDED is set.
-			 *
-			 * When a non-strict crl check fails, it is
-			 * left to the crl fetch job to do a refresh.
-			 *
-			 * Trigger a refresh.
-			 */
-			chunk_t fdn = empty_chunk;
-			if (find_crl_fetch_dn(&fdn, c)) {
-				/* FDN contains issuer_dn */
-				submit_crl_fetch_request(ASN1(fdn), st->st_logger);
-			}
-		}
-#endif
-		if (certs.harmless) {
-			/* For instance, no CA, unknown certs, ... */
-			return true;
-		} else {
-			log_state(RC_LOG, st,
-				    "X509: certificate rejected for this connection");
-			/* For instance, revoked */
-			return false;
-		}
-	}
-
-	pexpect(st->st_remote_certs.pubkey_db == NULL);
-	st->st_remote_certs.pubkey_db = certs.pubkey_db;
-	certs.pubkey_db = NULL;
-
-	pexpect(st->st_remote_certs.verified == NULL);
-	st->st_remote_certs.verified = certs.cert_chain;
-	certs.cert_chain = NULL;
-
-	statetime_stop(&start, "%s()", __func__);
-	return true;
-}
-
-/*
- * Decode the CR payload of Phase 1.
- *
- *  https://tools.ietf.org/html/rfc4945
- *  3.2.4. PKCS #7 wrapped X.509 certificate
- *
- *  This ID type defines a particular encoding (not a particular
- *  certificate type); some current implementations may ignore CERTREQs
- *  they receive that contain this ID type, and the editors are unaware
- *  of any implementations that generate such CERTREQ messages.
- *  Therefore, the use of this type is deprecated.  Implementations
- *  SHOULD NOT require CERTREQs that contain this Certificate Type.
- *  Implementations that receive CERTREQs that contain this ID type MAY
- *  treat such payloads as synonymous with "X.509 Certificate -
- *  Signature".
- */
-
-static void decode_certificate_request(struct state *st, enum ike_cert_type cert_type,
-				       const struct pbs_in *pbs)
-{
-	switch (cert_type) {
-	case CERT_X509_SIGNATURE:
-	{
-		asn1_t ca_name = pbs_in_left_as_shunk(pbs);
-
-		if (DBGP(DBG_BASE)) {
-			DBG_dump_hunk("CR", ca_name);
-		}
-
-		if (ca_name.len > 0) {
-			err_t e = asn1_ok(ca_name);
-			if (e != NULL) {
-				llog(RC_LOG_SERIOUS, st->st_logger,
-				     "ignoring CERTREQ payload that is not ASN1: %s", e);
-				return;
-			}
-
-			generalName_t *gn = alloc_thing(generalName_t, "generalName");
-			gn->name = clone_hunk(ca_name, "ca name");
-			gn->kind = GN_DIRECTORY_NAME;
-			gn->next = st->st_requested_ca;
-			st->st_requested_ca = gn;
-		}
-
-		if (DBGP(DBG_BASE)) {
-			dn_buf buf;
-			DBG_log("requested CA: '%s'",
-				str_dn_or_null(ca_name, "%any", &buf));
-		}
-		break;
-	}
-	default:
-	{
-		enum_buf b;
-		llog(RC_LOG_SERIOUS, st->st_logger,
-		     "ignoring CERTREQ payload of unsupported type %s",
-		     str_enum(&ikev2_cert_type_names, cert_type, &b));
-	}
-	}
-}
-
-void decode_v1_certificate_requests(struct state *st, struct msg_digest *md)
-{
-	for (struct payload_digest *p = md->chain[ISAKMP_NEXT_CR]; p != NULL; p = p->next) {
-		const struct isakmp_cr *const cr = &p->payload.cr;
-		decode_certificate_request(st, cr->isacr_type, &p->pbs);
-	}
-}
-
-void decode_v2_certificate_requests(struct state *st, struct msg_digest *md)
-{
-	for (struct payload_digest *p = md->chain[ISAKMP_NEXT_v2CERTREQ]; p != NULL; p = p->next) {
-		const struct ikev2_certreq *const cr = &p->payload.v2certreq;
-		decode_certificate_request(st, cr->isacertreq_enc, &p->pbs);
-	}
-}
-
-#if 0
-/*
- * returns the concatenated SHA-1 hashes of each public key in the chain
- */
-static chunk_t ikev2_hash_ca_keys(x509cert_t *ca_chain)
-{
-	unsigned char combined_hash[SHA1_DIGEST_SIZE * 8 /*max path len*/];
-	x509cert_t *ca;
-	chunk_t result = EMPTY_CHUNK;
-	size_t sz = 0;
-
-	zero(&combined_hash);
-
-	for (ca = ca_chain; ca != NULL; ca = ca->next) {
-		unsigned char sighash[SHA1_DIGEST_SIZE];
-		SHA1_CTX ctx_sha1;
-
-		SHA1Init(&ctx_sha1);
-		SHA1Update(&ctx_sha1, ca->signature.ptr, ca->signature.len);
-		SHA1Final(sighash, &ctx_sha1);
-
-		if (DBGP(DBG_CRYPT)) {
-			DBG_dump("SHA-1 of CA signature",
-				 sighash, SHA1_DIGEST_SIZE);
-		}
-
-		memcpy(combined_hash + sz, sighash, SHA1_DIGEST_SIZE);
-		sz += SHA1_DIGEST_SIZE;
-	}
-	passert(sz <= sizeof(combined_hash));
-	result = clone_bytes_as_chunk(combined_hash, sz, "combined CERTREQ hash");
-	if (DBGP(DBG_CRYPT)) {
-		DBG_dump_hunk("Combined CERTREQ hashes", result);
-	}
-	return result;
-}
-#endif
-
 /*
  * Look for the existence of a non-expiring preloaded public key.
  */
@@ -945,8 +700,8 @@ bool remote_has_preloaded_pubkey(const struct state *st)
 		     p = p->next) {
 			const struct pubkey *key = p->key;
 
-			if ((key->type == &pubkey_type_rsa ||
-			     key->type == &pubkey_type_ecdsa) &&
+			if ((key->content.type == &pubkey_type_rsa ||
+			     key->content.type == &pubkey_type_ecdsa) &&
 			    same_id(&c->remote->host.id, &key->id) &&
 			    is_realtime_epoch(key->until_time)) {
 				/* found a preloaded public key */
@@ -957,40 +712,6 @@ bool remote_has_preloaded_pubkey(const struct state *st)
 	return false;
 }
 
-bool ikev1_ship_CERT(enum ike_cert_type type, shunk_t cert, pb_stream *outs)
-{
-	pb_stream cert_pbs;
-	struct isakmp_cert cert_hd = {
-		.isacert_type = type,
-		.isacert_reserved = 0,
-		.isacert_length = 0, /* XXX unused on sending ? */
-	};
-
-	if (!out_struct(&cert_hd, &isakmp_ipsec_certificate_desc, outs,
-				&cert_pbs) ||
-	    !out_hunk(cert, &cert_pbs, "CERT"))
-		return false;
-
-	close_output_pbs(&cert_pbs);
-	return true;
-}
-
-bool ikev1_build_and_ship_CR(enum ike_cert_type type,
-			     chunk_t ca, pb_stream *outs)
-{
-	pb_stream cr_pbs;
-	struct isakmp_cr cr_hd = {
-		.isacr_type = type,
-	};
-
-	if (!out_struct(&cr_hd, &isakmp_ipsec_cert_req_desc, outs, &cr_pbs) ||
-	    (ca.ptr != NULL && !out_hunk(ca, &cr_pbs, "CA")))
-		return false;
-
-	close_output_pbs(&cr_pbs);
-	return true;
-}
-
 static bool cert_has_private_key(CERTCertificate *cert, struct logger *logger)
 {
 	if (cert == NULL)
