@@ -40,7 +40,8 @@ REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS debug.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS impair.sed"
 
 # The following sanitizers are written to only modify specific commands
-REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-setkey.sed" # BSD
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-setkey.sed"	# NetBSD FreeBSD
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-ipsecctl.sed"	# OpenBSD
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ephemeral-ports.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-ip-route.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-ip-addr.sed"
@@ -52,6 +53,7 @@ REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-certutil.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-cp.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-tcpdump.sed"
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-taskset.sed"
-REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-auto-up.n.sed"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS ipsec-auto-up.sed-n"
+REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS pem.sed-n"
 # this is last
 REF_CONSOLE_FIXUPS="$REF_CONSOLE_FIXUPS guest-prompt-double.sed"
