@@ -1,7 +1,8 @@
 /testing/guestbin/swan-prep
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
-ipsec whack --debug-all --impair retransmits
+../../guestbin/wait-until-pluto-started
+# suffer a quick death
+ipsec whack --impair delete-on-retransmit
 ipsec auto --add westnet-eastnet
 ipsec auto --add westnet-eastnet-ikev2
 echo "initdone"
