@@ -6,8 +6,8 @@ echo "192.1.2.0/24"  >> /etc/ipsec.d/policies/clear-or-private
 echo "192.1.3.0/24"  >> /etc/ipsec.d/policies/clear-or-private
 restorecon -R /etc/ipsec.d
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec whack --impair suppress-retransmits
 # give OE policies time to load
-sleep 5
+../../guestbin/wait-for.sh --match 'loaded 11' -- ipsec auto --status
 echo "initdone"
