@@ -2,16 +2,14 @@
 ipsec whack --trafficstatus
 # try triggering again, ondemand policy should re-trigger OE
 ip xfrm state
-ip xfrm pol
+ip xfrm policy
 # we use a different trigger so we do not hit original left over larval state
-hping -c 1 --udp  192.1.2.23
-# wait on OE to re-establish IPsec SA
-sleep 5
-ip xfrm state
-ip xfrm pol
-# should show established tunnel and no bare shunts
-ipsec whack --trafficstatus
+echo hi | socat - UDP4:192.1.2.23:1
+# wait on OE to re-establish IPsec SA; should show established tunnel and no bare shunts
+../../guestbin/wait-for.sh --match private-or-clear -- ipsec whack --trafficstatus
 ipsec whack --shuntstatus
+ip xfrm state
+ip xfrm policy
 # ping should succeed through tunnel
-ping -n -c 2 -I 192.1.3.209 192.1.2.23
+../../guestbin/ping-once.sh --up -I 192.1.3.209 192.1.2.23
 ipsec whack --trafficstatus
