@@ -20,6 +20,8 @@ ipsec timecheck > /dev/null || echo failed
 ipsec hunkcheck > /dev/null || echo failed
 ipsec dncheck > /dev/null || echo failed
 ipsec keyidcheck > /dev/null || echo failed
+ipsec asn1check > /dev/null || echo failed
+ipsec vendoridcheck > /dev/null || echo failed
 
 # Need to disable DNS tests; localhost is ok
 ipsec ipcheck --dns=hosts-file > /dev/null || echo failed
