@@ -1,6 +1,6 @@
 # wait for east to initiate to us
 sleep 10
-ping -n -c 4 -I 192.0.1.254 192.0.2.254
+../../guestbin/ping-once.sh --up -I 192.0.1.254 192.0.2.254
 # should show non-zero traffic counters
 ipsec whack --trafficstatus
 # sending delete/notify should cause east to re-initiate
