@@ -1,9 +1,9 @@
 : we can transmit in the clear
-ping -q -c 8 -n -I 192.1.2.45 192.1.2.23
+../../guestbin/ping-once.sh --up -I 192.1.2.45 192.1.2.23
 : bring up the tunnel
 ipsec auto --up west-east
 : use the tunnel
-ping -q -c 8 -n -I 192.1.2.45 192.1.2.23
+../../guestbin/ping-once.sh --up -I 192.1.2.45 192.1.2.23
 : show the tunnel
 ipsec whack --trafficstatus
 : Let R_U_THERE packets flow
