@@ -1,7 +1,6 @@
 /testing/guestbin/swan-prep --fips
-fipscheck
 setenforce 0
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add westnet-eastnet
 echo "initdone"
