@@ -1,5 +1,5 @@
 /testing/guestbin/swan-prep --x509
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add north-east
 echo "initdone"
