@@ -1,7 +1,7 @@
 /testing/guestbin/swan-prep --x509
 certutil -D -n west -d sql:/etc/ipsec.d
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec whack --impair suppress-retransmits
 ipsec auto --add san
 echo "initdone"
