@@ -1,4 +1,4 @@
 /testing/guestbin/swan-prep
 : > /etc/ipsec.secrets
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
