@@ -1,7 +1,7 @@
 /testing/guestbin/swan-prep
 cp policies/* /etc/ipsec.d/policies/
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add road-eastnet-nonat
 ipsec auto --status
 echo "initdone"
