@@ -6,7 +6,7 @@ ip addr add 192.1.3.34/24 dev eth1
 ip route add 0.0.0.0/0 via 192.1.3.254 dev eth1
 killall -9 pluto
 ipsec restart
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 # temp while the test still fails
 ipsec whack --impair suppress-retransmits
 ipsec auto --add road-eastnet-ikev2
