@@ -1,7 +1,7 @@
 #!/bin/sh
-ping -q -n -c 2 192.1.2.23
+../../guestbin/ping-once.sh --up 192.1.2.23
 ipsec auto --up road-east-x509-ipv4
-ping -q -n -c 4 -I 192.0.2.100 192.1.2.23
+../../guestbin/ping-once.sh --up -I 192.0.2.100 192.1.2.23
 ipsec whack --trafficstatus
 # Let R_U_THERE packets flow
 echo "Waiting 15 seconds..."
@@ -15,8 +15,8 @@ sleep 50
 echo "road should be retrying again. Remove the block"
 iptables -D INPUT -s 192.1.2.23/32 -d 0/0 -j DROP
 iptables -D OUTPUT -d 192.1.2.23/32 -s 0/0 -j DROP
-../../pluto/bin/ipsec-look.sh
+../../guestbin/ipsec-look.sh
 echo "sleep 110 seconds"
 sleep 60
-ping -q -n -c 4 -I 192.0.2.100 192.1.2.23
+../../guestbin/ping-once.sh --up -I 192.0.2.100 192.1.2.23
 echo done
