@@ -1,9 +1,9 @@
 #!/bin/sh
-ping -c 4 -q -n 192.1.2.23
+ping -n -q -c 4 192.1.2.23
 ipsec auto --up road-east-x509-ipv4
-ping -c 4 -q -n -I 192.0.2.100 192.1.2.23
+ping -n -q -c 4 -I 192.0.2.100 192.1.2.23
 ipsec whack --trafficstatus
-ping -c 1230000 -q -n -f -I 192.0.2.100 192.1.2.23 &
+ping -n -q -c 1230000 -f -I 192.0.2.100 192.1.2.23 &
 sleep 60
 sleep 60
 grep -E  'EVENT_SA_EXPIRE|EVENT_SA_REPLACE' OUTPUT/road.pluto.log  | head -9
