@@ -1,6 +1,6 @@
 /testing/guestbin/swan-prep
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add westnet-eastnet-ikev2
 # should be unoriented
 ipsec auto --status | grep westnet-eastnet-ikev2 | grep orient
