@@ -2,14 +2,14 @@
 # we meed to pickup stock secrets for raw rsa key
 echo '@east @west : PSK "ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"' >> /etc/ipsec.secrets
 # confirm that the network is alive
-../../pluto/bin/wait-until-alive -I 192.0.1.254 192.0.2.254
+../../guestbin/wait-until-alive -I 192.0.1.254 192.0.2.254
 # ensure that clear text does not get through
 iptables -A INPUT -i eth1 -s 192.0.2.0/24 -j DROP
 iptables -I INPUT -m policy --dir in --pol ipsec -j ACCEPT
 # confirm clear text does not get through
-../../pluto/bin/ping-once.sh --down -I 192.0.1.254 192.0.2.254
+../../guestbin/ping-once.sh --down -I 192.0.1.254 192.0.2.254
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add westnet-eastnet-ikev2
 ipsec auto --status | grep westnet-eastnet-ikev2
 echo "initdone"
