@@ -1,6 +1,6 @@
 /testing/guestbin/swan-prep
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
-ipsec whack --debug-all --impair send-bogus-dcookie
+../../guestbin/wait-until-pluto-started
+ipsec whack --impair send-bogus-dcookie
 ipsec auto --add westnet-eastnet-ikev2
 echo "initdone"
