@@ -9,7 +9,7 @@ iptables -A INPUT -i eth1 -s 192.0.200.0/24 -j DROP
 iptables -A INPUT -i eth1 -s 192.0.201.0/24 -j DROP
 iptables -I INPUT -m policy --dir in --pol ipsec -j ACCEPT
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec whack --debug-all --impair suppress-retransmits
 ipsec auto --add westnet-eastnet-a
 ipsec auto --add westnet-eastnet-b
