@@ -3,9 +3,9 @@
 # see: https://github.com/libreswan/libreswan/issues/368
 ipsec auto --up ikev2-westnet-eastnet
 sleep 3
-ping -n -c4 -I 192.0.1.254 192.0.2.254
+ping -n -q -c 4 -I 192.0.1.254 192.0.2.254
 ipsec whack --trafficstatus
 # should show tcp being used
-../../pluto/bin/ipsec-look.sh | grep encap
+../../guestbin/ipsec-look.sh 2>/dev/null | grep encap
 ipsec auto --down ikev2-westnet-eastnet
 echo "done"
