@@ -1,3 +1,3 @@
 ipsec whack --trafficstatus
 # ESP should show TFC for west and east
-grep "^[^|].*: established Child SA" /tmp/pluto.log
+grep "^[^|].* established Child SA" /tmp/pluto.log
