@@ -4,7 +4,7 @@ ipsec initnss > /dev/null 2> /dev/null
 pk12util -i OUTPUT/nss/client.p12 -d sql:/etc/ipsec.d -K 'foobar' -W 'foobar'
 certutil -M -d sql:/etc/ipsec.d -n cacert -t 'CT,,'
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add x509
 ipsec auto --add x509-comma-comma
 # show both conns are interpreted with \,
