@@ -2,5 +2,5 @@
 ipsec start
 ../../guestbin/wait-until-pluto-started
 ipsec auto --add westnet-eastnet-ikev2
-ipsec whack --impair ignore-hash-notify
+ipsec whack --impair ignore-v2n-signature-hash-algorithms
 echo "initdone"
