@@ -1,6 +1,6 @@
 /testing/guestbin/swan-prep --46
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add east
 ipsec auto --status | grep east
 echo "initdone"
