@@ -1,6 +1,6 @@
-# use -w due to local block policy
-ping -n -w 2 -c 1 -I 192.1.3.209 192.1.2.23
-# wait on OE retransmits and rekeying
+# blocked
+../../guestbin/ping-once.sh --down -I 192.1.3.209 192.1.2.23
+# (pointlessly) wait on OE retransmits and rekeying
 sleep 5
 # no tunnel and no bare shunts expected
 ipsec whack --trafficstatus
@@ -9,5 +9,5 @@ ipsec whack --shuntstatus
 killall ip > /dev/null 2> /dev/null
 cp /tmp/xfrm-monitor.out OUTPUT/road.xfrm-monitor.txt
 # ping should fail on outgoing block rule
-ping -n -w 2 -c 2 -I 192.1.3.209 192.1.2.23
+../../guestbin/ping-once.sh --down -I 192.1.3.209 192.1.2.23
 echo done
