@@ -1,13 +1,13 @@
-# use -w due to local block policy
-ping -w 2 -n -c 1 -I 192.1.3.209 192.1.2.23
+# blocked
+../../guestbin/ping-once.sh --down -I 192.1.3.209 192.1.2.23
 # wait on OE retransmits and rekeying
 sleep 5
 # no tunnel and no bare shunts expected
 ipsec whack --trafficstatus
 ipsec whack --shuntstatus
-../../pluto/bin/ipsec-look.sh
+../../guestbin/ipsec-look.sh
 killall ip > /dev/null 2> /dev/null
 cp /tmp/xfrm-monitor.out OUTPUT/road.xfrm-monitor.txt
 # ping should fail on outgoing block rule
-ping -w 2 -n -c 2 -I 192.1.3.209 192.1.2.23
+../../guestbin/ping-once.sh --down -I 192.1.3.209 192.1.2.23
 echo done
