@@ -2,8 +2,8 @@
 cp policies/* /etc/ipsec.d/policies/
 echo "192.1.2.23/32"  >> /etc/ipsec.d/policies/private
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 # give OE policies time to load
-sleep 5
+../../guestbin/wait-for.sh --match 'loaded 10,' -- ipsec auto --status
 ip -s xfrm monitor > /tmp/xfrm-monitor.out &
 echo "initdone"
