@@ -2,7 +2,7 @@
 certutil -d sql:/etc/ipsec.d -D -n east
 pk12util -W foobar -K '' -d sql:/etc/ipsec.d -i /testing/x509/pkcs12/mainca/usage-client.p12
 ipsec start
-/testing/pluto/bin/wait-until-pluto-started
+../../guestbin/wait-until-pluto-started
 ipsec auto --add nss-cert
 ipsec auto --status |grep nss-cert
 ipsec whack --impair suppress-retransmits
