@@ -1,5 +1,5 @@
 ipsec whack --xauthname 'use3' --xauthpass 'use1pass' --name modecfg-road-eastnet-psk --initiate
-ping -n -c 4 -I 192.0.2.209 192.0.2.254
+../../guestbin/ping-once.sh --up -I 192.0.2.209 192.0.2.254
 ipsec whack --trafficstatus
 # check to see if our resolv.conf got updated
 cat /etc/resolv.conf
