@@ -67,7 +67,7 @@ def main():
     parser.add_argument("--print", action="store",
                         default=printer.Print(printer.Print.PATH, printer.Print.RESULT, printer.Print.ISSUES),
                         type=printer.Print, metavar=str(printer.Print),
-                        help="comman separate list of attributes to print for each test; default: '%(default)s'")
+                        help="comma separated list of attributes to print for each test; default: '%(default)s'")
 
     parser.add_argument("--stats", action="store", default=Stats.summary, type=Stats,
                         choices=[c for c in Stats],
@@ -122,7 +122,7 @@ def main():
     # Try to find a baseline.  If present, pre-load it.
     baseline = None
     if args.baseline:
-        # An explict baseline testsuite, can be more forgiving in how
+        # An explicit baseline testsuite, can be more forgiving in how
         # it is loaded.
         baseline = testsuite.load(logger, logutil.DEBUG, args,
                                   testsuite_directory=args.baseline,
@@ -167,8 +167,6 @@ def main():
             result_stats.log_details(stderr_log, header="Details:", prefix="  ")
         if args.stats in [Stats.details, Stats.summary]:
             result_stats.log_summary(stderr_log, header="Summary:", prefix="  ")
-        publish.json_results(logger, args)
-        publish.json_summary(logger, args)
 
     return exit_code
 
@@ -183,13 +181,17 @@ def results(logger, tests, baseline, args, result_stats):
     failures = 0
     unresolved = 0
     passed = 0
+    nr = 0
 
     for test in tests:
 
-        publish.json_status(logger, args, "rebuilding %s" % test.name)
+        nr = nr + 1
+        publish.json_status(logger, args,
+                            "rebuilding %s (test %d of %d)" % (test.name, nr, len(tests)))
 
         # If debug logging is enabled this will provide fine grained
         # per-test timing.
+
         with logger.debug_time("processing test %s", test.name):
 
             # Filter out tests that are being ignored?
@@ -207,7 +209,7 @@ def results(logger, tests, baseline, args, result_stats):
             # This is noticeable when printing static test value such
             # as the test's name takes far longer than one would
             # expect.
-            result = post.mortem(test, args,
+            result = post.mortem(test, args, logger,
                                  baseline=baseline,
                                  output_directory=test.saved_output_directory,
                                  quick=args.quick)
@@ -247,6 +249,9 @@ def results(logger, tests, baseline, args, result_stats):
             b = args.json and printer.JsonBuilder(sys.stdout) or printer.TextBuilder(sys.stdout)
             printer.build_result(logger, result, baseline, args, args.print, b)
 
+        publish.json_results(logger, args)
+        publish.json_summary(logger, args)
+
     publish.json_status(logger, args, "finished")
 
     # exit code
