@@ -23,7 +23,7 @@ function lsw_directory_hash(path) {
     if (!path) {
 	return undefined
     }
-    var npath = path.replace(/.*-g([^-]*)-.*/, "$1")
+    let npath = path.replace(/.*-g([^-]*)-.*/, "$1")
     if (npath == path) {
 	return undefined
     }
@@ -31,8 +31,8 @@ function lsw_directory_hash(path) {
 }
 
 function lsw_summary_load(prefix, f) {
-    var now = Date()
-    var q = d3.queue()
+    let now = Date()
+    let q = d3.queue()
     q.defer(d3.json, prefix + "status.json?" + now)
     q.await(function(error, status) {
 	if (error) {
@@ -43,7 +43,7 @@ function lsw_summary_load(prefix, f) {
 
 	// Generate a tag for fetching big stuff that changes once
 	// per-directory.
-	var tag = "?"
+	let tag = "?"
 	if (status) {
 	    if (status.directory) {
 		// a current directory, assume commits.json was
@@ -62,7 +62,7 @@ function lsw_summary_load(prefix, f) {
 	}
 
 	// pull in the commits and subdirectories.
-	var q = d3.queue()
+	let q = d3.queue()
 	q.defer(d3.json, prefix + "commits.json" + tag)
 	q.defer(d3.json, prefix + "summaries.json" + tag)
 	// also fetch the current directory's summary; it might not be
@@ -79,7 +79,7 @@ function lsw_summary_load(prefix, f) {
 	    console.log("summaries:", summaries.length)
 	    console.log("current:", current)
 
-	    var summary = lsw_summary_cleanup(status, commits, summaries, current)
+	    let summary = lsw_summary_cleanup(status, commits, summaries, current)
 	    f(summary)
 	})
     })
@@ -88,15 +88,15 @@ function lsw_summary_load(prefix, f) {
 function lsw_summary_cleanup(status, commits, summaries, current) {
 
 
-    var summary = {}
+    let summary = {}
 
     // Create "summary.current" by merging current into status.
 
     summary.current = status
     if (current) {
-	Object.keys(current).forEach(function(key) {
+	for (const key of Object.keys(current)) {
 	    status[key] = current[key]
-	})
+	}
     }
     // probably redundant; but easier
     lsw_cleanup_dates(summary.current, ["date"])
@@ -105,7 +105,7 @@ function lsw_summary_cleanup(status, commits, summaries, current) {
     // Clean up the commits discarding anything strange.  Accumulate a
     // table containing all the commits.
 
-    var commit_by_hash = []
+    let commit_by_hash = []
     summary.commits = commits.filter(function (commit) {
 	// Fix values
 	if (!lsw_cleanup_dates(commit.author, ["date"])) {
@@ -117,7 +117,7 @@ function lsw_summary_cleanup(status, commits, summaries, current) {
 	    return false
 	}
 	// add to the lookup table
-	var hash = commit.hash
+	let hash = commit.hash
 	if (!hash) {
 	    console.log("discarding commit with no hash", commit)
 	    return false
@@ -136,16 +136,16 @@ function lsw_summary_cleanup(status, commits, summaries, current) {
     // Using the above hash->commit table, fill in the .parent[] and
     // .children[] fields from the relevant hashes.
 
-    summary.commits.forEach(function (commit) {
-	commit.parent_hashes.forEach(function (parent_hash) {
-	    var parent = commit_by_hash[parent_hash]
+    for (const commit of summary.commits) {
+	for (parent_hash of commit.parent_hashes) {
+	    let parent = commit_by_hash[parent_hash]
 	    if (parent) {
 		// cross link the parent and child
 		commit.parents.push(parent)
 		parent.children.push(commit)
 	    }
-	})
-    })
+	}
+    }
 
     // Clean up the result values discarding anything strange.
     //
@@ -171,13 +171,13 @@ function lsw_summary_cleanup(status, commits, summaries, current) {
 	    return false
 	}
 	// Try to cross link commit and test_run
-	var hash = test_run.hash
+	let hash = test_run.hash
 	if (!hash) {
 	    console.warn("discarding test run", test_run, "at", index, "with a missing .hash")
 	    return false
 	}
 	// Cross link when possible.
-	var commit = commit_by_hash[hash]
+	let commit = commit_by_hash[hash]
 	if (!commit) {
 	    console.warn("discarding test run", test_run, "at", index, "with commit matching .hash")
 	    return false
@@ -188,36 +188,43 @@ function lsw_summary_cleanup(status, commits, summaries, current) {
 	return true
     })
 
-    // Sort the test run by committer.date in assending order.
+    // Sort the test run by committer.date in ascending order.
 
     summary.test_runs.sort(function(l, r) {
 	return l.commit.committer.date - r.commit.committer.date
     })
 
-    // Use the commit<->test_run and commit.parent[] links created
-    // above to find the commits unique to this test run.  Cross link
-    // those additional commits back to the test.
+    summary.test_run_by_directory = []
+    for (const test_run of summary.test_runs) {
+
+	// Create a dictionary of directory->test_run so that
+	// ?run=<directory> can find them
+
+	summary.test_run_by_directory[test_run.directory] = test_run
+
+	// Use the commit<->test_run and commit.parent[] links created
+	// above to find the commits unique to this test run.  Cross
+	// link those additional commits back to the test.
 
-    summary.test_runs.forEach(function(test_run) {
 	test_run.commits = lsw_summary_commits(test_run.commit)
-	test_run.commits.forEach(function(commit) {
+	for (const commit of test_run.commits) {
 	    // One of these assignments is redundant, oops.
 	    commit.test_run = test_run;
-	})
-    })
+	}
+    }
 
     return summary
 }
 
 function lsw_commit_texts(commits) {
-    var subject = ""
-    commits.forEach(function(commit) {
+    let subject = ""
+    for (const commit of commits) {
 	subject = (subject
 		   + lsw_date2iso(commit.committer.date)
 		   + ": "
 		   + commit.subject
 		   + "\n")
-    })
+    }
     return subject
 }
 
@@ -225,12 +232,12 @@ function lsw_commit_texts(commits) {
 // all commits for a test_run.
 
 function lsw_summary_commits(commit) {
-    var commits = []
+    let commits = []
     if (commit) {
 	commits.push(commit)
-	var parents = commit.parents.slice()
+	let parents = commit.parents.slice()
 	while (parents.length) {
-	    var parent = parents.shift()
+	    let parent = parents.shift()
 	    if (parent.test_run) {
 		// stop when there is a test_run
 		continue
@@ -276,7 +283,7 @@ var lsw_abbrev_hash_length = 9
 function lsw_commits_html(commits) {
     html = ""
     html += "<table class=\"commits\"><tbody class=\"commits\">"
-    commits.forEach(function(commit) {
+    for (const commit of commits) {
 	html += "<tr class=\"" + commit.interesting + "\" title=\"interesting commit: " + commit.interesting + "\">"
 	html += "<td class=\"date\">"
 	html += lsw_date2iso(commit.committer.date)
@@ -293,24 +300,7 @@ function lsw_commits_html(commits) {
 	html += lsw_html_escape(commit.subject)
 	html += "</td>"
 	html += "</tr>"
-    })
+    }
     html += "</tbody></table>"
     return html
 }
-
-// Return the errors as a blob of HTML.
-
-function lsw_errors_html(errors) {
-    var html = ""
-    if (errors) {
-	html += "<div class=\"errors\">"
-	Object.keys(errors).sort().forEach(function(error) {
-	    // only real errors are UPPER CASE?
-	    if (error == error.toUpperCase()) {
-		html += error + ": " + errors[error] + "<br>"
-	    }
-	})
-	html += "</div>"
-    }
-    return html
-}
